==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/zh_CN.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "此服务器未启用服务器到服务器分享功能",
    "The mountpoint name contains invalid characters." : "挂载点的名称包含无效字符。",
    "Not allowed to create a federated share with the same user server" : "不允许使用相同的用户服务器创建联合共享",
    "Invalid or untrusted SSL certificate" : "无效或是不被信任的 SSL 证书",
    "Could not authenticate to remote share, password might be wrong" : "无法验证远程共享，可能是密码错误",
    "Storage not valid" : "存储无效",
    "Couldn't add remote share" : "无法添加远程分享",
    "Shared with you" : "分享给您的文件",
    "Shared with others" : "您分享的文件",
    "Shared by link" : "分享链接的文件",
    "Uploading..." : "上传中...",
    "Nothing shared with you yet" : "你还没有收到任何共享的文件",
    "Files and folders others share with you will show up here" : "其它人共享给您的文件和文件夹将显示在这里",
    "Nothing shared yet" : "还没有共享过文件",
    "Files and folders you share will show up here" : "您共享的文件和文件夹将显示在这里",
    "No shared links" : "无分享链接",
    "Files and folders you share by link will show up here" : "您通过链接共享的文件和文件夹将显示在这里",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "您要添加 {name} 来自 {owner}@{remote} 的远程分享吗？",
    "Remote share" : "远程分享",
    "Remote share password" : "远程分享密码",
    "Cancel" : "取消",
    "Add remote share" : "添加远程分享",
    "You can upload into this folder" : "您可以上传文件至此文件夹",
    "No ownCloud installation (7 or higher) found at {remote}" : "未发现 {remote} 安装有ownCloud (7 或更高版本)",
    "Invalid ownCloud url" : "无效的 ownCloud 网址",
    "Share" : "共享",
    "No expiration date set" : "过期时间未设置",
    "Shared by" : "共享人",
    "Sharing" : "共享",
    "Share API is disabled" : "共享 API 已被禁用",
    "Wrong share ID, share doesn't exist" : "错误的共享 ID，共享不存在",
    "Could not delete share" : "不能删除共享",
    "Please specify a file or folder path" : "请指定一个文件或文件夹路径",
    "Wrong path, file/folder doesn't exist" : "路径错误，文件/文件夹不存在",
    "Please specify a valid user" : "请指定一个有效的用户",
    "Group sharing is disabled by the administrator" : "群组共享已被管理员禁用",
    "Please specify a valid group" : "请指定一个有效的组",
    "Public link sharing is disabled by the administrator" : "公共链接共享已被管理员禁用",
    "Public upload disabled by the administrator" : "公共上传已被管理员禁用",
    "Public upload is only possible for publicly shared folders" : "公共上传仅适用于公共共享文件夹",
    "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "共享 %s 失败，后端不允许共享 %s 类型",
    "Unknown share type" : "未知共享类型",
    "Not a directory" : "不是一个目录",
    "Could not lock path" : "无法锁定路径",
    "Can't change permissions for public share links" : "不能改变公共分享链接权限",
    "Wrong or no update parameter given" : "错误或没有更新参数给出",
    "Cannot increase permissions" : "不能增加权限",
    "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>。",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>其它服务器</strong> 中一个文件或者文件夹被共享 ",
    "A public shared file or folder was <strong>downloaded</strong>" : "一个公共共享的文件或文件夹<strong>已下载</strong>",
    "You received a new remote share %2$s from %1$s" : "您收到一个新的远程共享 %2$s 来自于 %1$s",
    "You received a new remote share from %s" : "您从%s收到了新的远程分享",
    "%1$s accepted remote share %2$s" : "%1$s 接受了远程分享 %2$s",
    "%1$s declined remote share %2$s" : "%1$s 拒绝了远程分享 %2$s",
    "%1$s unshared %2$s from you" : "%1$s 未共享你的 %2$s ",
    "Public shared folder %1$s was downloaded" : "公共共享文件夹 %1$s 已被下载",
    "Public shared file %1$s was downloaded" : "公共共享文件 %1$s 已被下载",
    "You shared %1$s with %2$s" : "您把 %1$s分享给了 %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s 共享 %1$s 给 %3$s",
    "You removed the share of %2$s for %1$s" : "你移除了 %2$s 的共享 %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s 移除了 %3$s 的共享 %1$s",
    "You shared %1$s with group %2$s" : "你把 %1$s 分享给了 %2$s 组",
    "%2$s shared %1$s with group %3$s" : "%2$s 共享 %1$s 给群组 %3$s",
    "You removed the share of group %2$s for %1$s" : "你移除了组 %2$s 的共享 %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s 移除了组 %3$s 的共享 %1$s",
    "%2$s shared %1$s via link" : "%2$s 以链接方式共享 %1$s",
    "You shared %1$s via link" : "您通过链接共享了 %1$s",
    "You removed the public link for %1$s" : "你移除了公共链接 %1$s",
    "%2$s removed the public link for %1$s" : "%2$s 移除了公共链接 %1$s",
    "Your public link for %1$s expired" : "你的公开链接 %1$s 已过期",
    "The public link of %2$s for %1$s expired" : "%2$s 的公开链接 %1$s 已过期",
    "%2$s shared %1$s with you" : "%2$s 把 %1$s 分享给了您",
    "%2$s removed the share for %1$s" : "%2$s 移除了共享 %1$s",
    "Downloaded via public link" : "通过公开链接下载",
    "Shared with %2$s" : "共享给 %2$s",
    "Shared with %3$s by %2$s" : "由 %2$s 共享给 %3$s",
    "Removed share for %2$s" : "移除共享 %2$s",
    "%2$s removed share for %3$s" : "%2$s 移除共享 %3$s",
    "Shared with group %2$s" : "共享给组%2$s",
    "Shared with group %3$s by %2$s" : "由 %2$s 共享给组 %3$s",
    "Removed share of group %2$s" : "移除了组 %2$s 的共享",
    "%2$s removed share of group %3$s" : "%2$s 移除了群 %3$s 的共享",
    "Shared via link by %2$s" : "%2$s 以链接方式共享",
    "Shared via public link" : "通过公开链接共享",
    "Removed public link" : "移除公开链接",
    "%2$s removed public link" : "%2$s 移除了公共链接",
    "Public link expired" : "公开链接已过期",
    "Public link of %2$s expired" : "%2$s 的公开链接已过期",
    "Shared by %2$s" : "由 %2$s 共享",
    "Shares" : "共享",
    "This share is password-protected" : "这是一个密码保护的共享",
    "The password is wrong. Try again." : "用户名或密码错误！请重试",
    "Password" : "密码",
    "No entries found in this folder" : "此文件夹中无项目",
    "Name" : "名称",
    "Share time" : "分享时间",
    "Expiration date" : "过期日期",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此链接已失效",
    "Reasons might be:" : "可能原因是：",
    "the item was removed" : "此项已移除",
    "the link expired" : "链接过期",
    "sharing is disabled" : "分享已禁用",
    "For more info, please ask the person who sent this link." : "欲知详情，请联系发给你链接的人。",
    "%s is publicly shared" : "%s 是公开共享的。",
    "Add to your ownCloud" : "添加到您的 ownCloud",
    "Download" : "下载",
    "Download %s" : "下载 %s",
    "Direct link" : "直接链接"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/zh_CN.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "此服务器未启用服务器到服务器分享功能",
    "The mountpoint name contains invalid characters." : "挂载点的名称包含无效字符。",
    "Not allowed to create a federated share with the same user server" : "不允许使用相同的用户服务器创建联合共享",
    "Invalid or untrusted SSL certificate" : "无效或是不被信任的 SSL 证书",
    "Could not authenticate to remote share, password might be wrong" : "无法验证远程共享，可能是密码错误",
    "Storage not valid" : "存储无效",
    "Couldn't add remote share" : "无法添加远程分享",
    "Shared with you" : "分享给您的文件",
    "Shared with others" : "您分享的文件",
    "Shared by link" : "分享链接的文件",
    "Uploading..." : "上传中...",
    "Nothing shared with you yet" : "你还没有收到任何共享的文件",
    "Files and folders others share with you will show up here" : "其它人共享给您的文件和文件夹将显示在这里",
    "Nothing shared yet" : "还没有共享过文件",
    "Files and folders you share will show up here" : "您共享的文件和文件夹将显示在这里",
    "No shared links" : "无分享链接",
    "Files and folders you share by link will show up here" : "您通过链接共享的文件和文件夹将显示在这里",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "您要添加 {name} 来自 {owner}@{remote} 的远程分享吗？",
    "Remote share" : "远程分享",
    "Remote share password" : "远程分享密码",
    "Cancel" : "取消",
    "Add remote share" : "添加远程分享",
    "You can upload into this folder" : "您可以上传文件至此文件夹",
    "No ownCloud installation (7 or higher) found at {remote}" : "未发现 {remote} 安装有ownCloud (7 或更高版本)",
    "Invalid ownCloud url" : "无效的 ownCloud 网址",
    "Share" : "共享",
    "No expiration date set" : "过期时间未设置",
    "Shared by" : "共享人",
    "Sharing" : "共享",
    "Share API is disabled" : "共享 API 已被禁用",
    "Wrong share ID, share doesn't exist" : "错误的共享 ID，共享不存在",
    "Could not delete share" : "不能删除共享",
    "Please specify a file or folder path" : "请指定一个文件或文件夹路径",
    "Wrong path, file/folder doesn't exist" : "路径错误，文件/文件夹不存在",
    "Please specify a valid user" : "请指定一个有效的用户",
    "Group sharing is disabled by the administrator" : "群组共享已被管理员禁用",
    "Please specify a valid group" : "请指定一个有效的组",
    "Public link sharing is disabled by the administrator" : "公共链接共享已被管理员禁用",
    "Public upload disabled by the administrator" : "公共上传已被管理员禁用",
    "Public upload is only possible for publicly shared folders" : "公共上传仅适用于公共共享文件夹",
    "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "共享 %s 失败，后端不允许共享 %s 类型",
    "Unknown share type" : "未知共享类型",
    "Not a directory" : "不是一个目录",
    "Could not lock path" : "无法锁定路径",
    "Can't change permissions for public share links" : "不能改变公共分享链接权限",
    "Wrong or no update parameter given" : "错误或没有更新参数给出",
    "Cannot increase permissions" : "不能增加权限",
    "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>。",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>其它服务器</strong> 中一个文件或者文件夹被共享 ",
    "A public shared file or folder was <strong>downloaded</strong>" : "一个公共共享的文件或文件夹<strong>已下载</strong>",
    "You received a new remote share %2$s from %1$s" : "您收到一个新的远程共享 %2$s 来自于 %1$s",
    "You received a new remote share from %s" : "您从%s收到了新的远程分享",
    "%1$s accepted remote share %2$s" : "%1$s 接受了远程分享 %2$s",
    "%1$s declined remote share %2$s" : "%1$s 拒绝了远程分享 %2$s",
    "%1$s unshared %2$s from you" : "%1$s 未共享你的 %2$s ",
    "Public shared folder %1$s was downloaded" : "公共共享文件夹 %1$s 已被下载",
    "Public shared file %1$s was downloaded" : "公共共享文件 %1$s 已被下载",
    "You shared %1$s with %2$s" : "您把 %1$s分享给了 %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s 共享 %1$s 给 %3$s",
    "You removed the share of %2$s for %1$s" : "你移除了 %2$s 的共享 %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s 移除了 %3$s 的共享 %1$s",
    "You shared %1$s with group %2$s" : "你把 %1$s 分享给了 %2$s 组",
    "%2$s shared %1$s with group %3$s" : "%2$s 共享 %1$s 给群组 %3$s",
    "You removed the share of group %2$s for %1$s" : "你移除了组 %2$s 的共享 %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s 移除了组 %3$s 的共享 %1$s",
    "%2$s shared %1$s via link" : "%2$s 以链接方式共享 %1$s",
    "You shared %1$s via link" : "您通过链接共享了 %1$s",
    "You removed the public link for %1$s" : "你移除了公共链接 %1$s",
    "%2$s removed the public link for %1$s" : "%2$s 移除了公共链接 %1$s",
    "Your public link for %1$s expired" : "你的公开链接 %1$s 已过期",
    "The public link of %2$s for %1$s expired" : "%2$s 的公开链接 %1$s 已过期",
    "%2$s shared %1$s with you" : "%2$s 把 %1$s 分享给了您",
    "%2$s removed the share for %1$s" : "%2$s 移除了共享 %1$s",
    "Downloaded via public link" : "通过公开链接下载",
    "Shared with %2$s" : "共享给 %2$s",
    "Shared with %3$s by %2$s" : "由 %2$s 共享给 %3$s",
    "Removed share for %2$s" : "移除共享 %2$s",
    "%2$s removed share for %3$s" : "%2$s 移除共享 %3$s",
    "Shared with group %2$s" : "共享给组%2$s",
    "Shared with group %3$s by %2$s" : "由 %2$s 共享给组 %3$s",
    "Removed share of group %2$s" : "移除了组 %2$s 的共享",
    "%2$s removed share of group %3$s" : "%2$s 移除了群 %3$s 的共享",
    "Shared via link by %2$s" : "%2$s 以链接方式共享",
    "Shared via public link" : "通过公开链接共享",
    "Removed public link" : "移除公开链接",
    "%2$s removed public link" : "%2$s 移除了公共链接",
    "Public link expired" : "公开链接已过期",
    "Public link of %2$s expired" : "%2$s 的公开链接已过期",
    "Shared by %2$s" : "由 %2$s 共享",
    "Shares" : "共享",
    "This share is password-protected" : "这是一个密码保护的共享",
    "The password is wrong. Try again." : "用户名或密码错误！请重试",
    "Password" : "密码",
    "No entries found in this folder" : "此文件夹中无项目",
    "Name" : "名称",
    "Share time" : "分享时间",
    "Expiration date" : "过期日期",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此链接已失效",
    "Reasons might be:" : "可能原因是：",
    "the item was removed" : "此项已移除",
    "the link expired" : "链接过期",
    "sharing is disabled" : "分享已禁用",
    "For more info, please ask the person who sent this link." : "欲知详情，请联系发给你链接的人。",
    "%s is publicly shared" : "%s 是公开共享的。",
    "Add to your ownCloud" : "添加到您的 ownCloud",
    "Download" : "下载",
    "Download %s" : "下载 %s",
    "Direct link" : "直接链接",
    "Anonymous upload" : "匿名上传",
    "Uploaded files" : "上传文件",
    "Click to select files or use drag & drop to upload" : "点击选择文件或拖拽上传",
    "Cannot remove all permissions" : "无法移除全部权限",
    "Pending" : "等待",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "Declined" : "拒绝"
},
"nplurals=1; plural=0;");
